'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var shiki = require('shiki');
var promises = require('fs/promises');

const defaultMapExtension = {
  svg: "xml"
};
const SYNTAX_SUFFIX = "?syntax";
const SYNTAX_EXTENSION = ".syntax";
const EXTENSION_REGEXP = /([^\.]+)(\.syntax)?$/;
function wrapPath(path) {
  return "\0" + path + SYNTAX_EXTENSION;
}
function unWrapPath(path) {
  return path.slice(1, path.lastIndexOf(SYNTAX_EXTENSION));
}
function syntaxHighlight(options) {
  const { mapExtension, ...shikiOptions } = {
    mapExtension: {
      ...defaultMapExtension,
      ...options?.mapExtension
    },
    ...options
  };
  return {
    name: "syntax-highlight",
    enforce: "pre",
    async resolveId(id, importer, options2) {
      if (!id.endsWith(SYNTAX_SUFFIX)) {
        return null;
      }
      const suffixIndex = id.indexOf(SYNTAX_SUFFIX);
      const path = id.slice(0, suffixIndex);
      const resolution = await this.resolve(path, importer, {
        skipSelf: true,
        ...options2
      });
      if (!resolution) {
        this.warn(`"${id}" couldn't be resolved, falling back to default`);
        return null;
      }
      return wrapPath(resolution.id);
    },
    async load(id) {
      if (!id.endsWith(SYNTAX_EXTENSION)) {
        return null;
      }
      const path = unWrapPath(id);
      let content;
      try {
        content = await promises.readFile(path, "utf-8");
      } catch (ex) {
        this.warn(`"${id}" couldn't be loaded, falling back to default`);
        return;
      }
      const extensionMatch = path.match(EXTENSION_REGEXP);
      if (!extensionMatch) {
        this.warn(`"${id}" doesn't have an extension, falling back to default`);
        return;
      }
      const extension = extensionMatch[1];
      const language = mapExtension[extension] || extension;
      const highlighter = await shiki.getHighlighter(shikiOptions);
      const code = highlighter.codeToHtml(content, { lang: language });
      return {
        code: `export default ${JSON.stringify(code)}`
      };
    }
  };
}

exports.syntaxHighlight = syntaxHighlight;
//# sourceMappingURL=index.js.map
